@@ -1,9 +1,12 @@
+from .Category import Category
+from .Company import Company
 from .DraftStatus import DraftStatus
 from .DraftType import DraftType
 from .InjuryStatus import InjuryStatus
 from .ModelEnum import ModelEnum
 from .PlayerPosition import PlayerPosition
 from .PlayerStatus import PlayerStatus
+from .PlayoffRoundType import PlayoffRoundType
 from .PracticeParticipation import PracticeParticipation
 from .RosterPosition import RosterPosition
 from .ScoringType import ScoringType
